@@ -6,6 +6,7 @@ from httplib2 import Http
 import oauth2 as oauth
 from pyutil import jsonutil as json
 from pyutil.assertutil import precondition
+import warnings
 
 from simplegeo.models import Feature
 from simplegeo.util import json_decode, APIError, SIMPLEGEOHANDLE_RSTR, is_simplegeohandle, to_unicode
@@ -38,7 +39,8 @@ class Client(object):
         self.signature = oauth.SignatureMethod_HMAC_SHA1()
         self.uri = "http://%s:%s" % (host, port)
         self.http = Http()
-        self.headers = None
+        self.req_headers = {}
+        self.headers = {}
 
         self.subclient = getattr(self, 'subclient', False)
 
@@ -57,6 +59,8 @@ class Client(object):
     def get_most_recent_http_headers(self):
         """ Intended for debugging -- return the most recent HTTP
         headers which were received from the server. """
+        warnings.warn('Please access self.headers directly instead of '
+                      'calling get_most_recent_http_headers().', DeprecationWarning)
         return self.headers
 
     def _endpoint(self, name, **kwargs):
@@ -131,8 +135,10 @@ class Client(object):
         request.sign_request(self.signature, self.consumer, None)
         headers = request.to_header(self.realm)
         headers['User-Agent'] = 'SimpleGeo Python Client v%s' % __version__
+        headers.update(self.req_headers)
 
-        self.headers, content = self.http.request(endpoint, method, body=body, headers=headers)
+        self.headers, content = self.http.request(endpoint, method, body=body,
+                                                  headers=headers)
 
         if self.headers['status'][0] not in ('2', '3'):
             raise APIError(int(self.headers['status']), content, self.headers)
